triton-windows
A language and compiler for custom Deep Learning operations
Decision gist · record as of 2026-08-14
Yes, if you need to write custom GPU kernels on Windows and your NVIDIA GPU and PyTorch version are compatible. The permissive license and active wheel distribution make it straightforward to install. No, if you need ongoing maintenance and support—the original repository is archived, though development continues at https://github.com/triton-lang/triton-windows. Verify PyTorch and CUDA version compatibility before installing.AI-flagged interpretation of the facts on this page — verify before relying
Before you install
- Requires Windows 10 or 11, NVIDIA GPU with supported compute capability, matching PyTorch version (e.g., PyTorch 2.7 requires Triton 3.3), and correct Python environment setup (embedded, system-wide, conda, or venv).
- Medium install friction: platform-specific wheels for Windows (cp310–cp314), requires matching Python environment and GPU driver setup.
- Repository is archived; development has moved to https://github.com/triton-lang/triton-windows, but pip installation continues to work.
License · maintenance · safety
permissive license (permissive) — Permissive license (MIT) means you can use this package freely in commercial and private projects without restriction.
last release 2026-06-21 (54 days) · last repo commit 2026-02-18 · 1,958 stars · archived
0 known vulnerabilities (OSV.dev, 2026-08-14) · 471,577 downloads/mo, #6,479 on PyPI
Alternatives
Verify before relying
pip install triton-windows
import triton
@triton.jit
def kernel(x_ptr, output_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
mask = offsets < n_elements
x = tl.load(x_ptr + offsets, mask=mask)
tl.store(output_ptr + offsets, x, mask=mask)- Whether AMD GPU support via the referenced pull request is production-ready or experimental.
- Current status and stability of free-threaded Python (3.13t/3.14t) support on Windows.
- Whether Proton profiler limitations affect your profiling workflow.
- Specific GPU compute capability requirements for different Triton versions on Windows.
What it is and what it does
Triton-windows is a Windows-native fork of the Triton compiler, which allows you to write high-performance GPU kernels in Python and compile them just-in-time for NVIDIA GPUs. It bridges the gap between Python's ease of use and the performance demands of deep learning by letting you write custom operations that standard libraries don't cover, then compiling them directly to GPU code at runtime.
The package is designed specifically for Windows environments where the upstream Triton project did not have native support. It works with torch.compile and Triton's @triton.jit decorator, and passes all unit tests. Installation requires careful environment setup—you must ensure your Python version, PyTorch version, and GPU driver are aligned according to the documented compatibility matrix, and the package provides wheels only for Python 3.10–3.14 on Windows x86-64.
Use it for
- Accelerate custom deep learning operations on Windows by compiling hand-written GPU kernels instead of relying on standard libraries.
- Optimize matrix multiplication, attention mechanisms, or other compute-intensive layers by writing Triton kernels tailored to your model's needs.
- Use torch.compile with Triton on Windows to automatically fuse and compile operations into efficient GPU code.
- Prototype and deploy GPU-accelerated algorithms on Windows without dropping to lower-level GPU programming or managing low-level GPU memory manually.
Worth the install?
AI-flagged interpretation of the facts on this page. Verify before relying on it.
Yes, if you need to write custom GPU kernels on Windows and your NVIDIA GPU and PyTorch version are compatible.
The permissive license and active wheel distribution make it straightforward to install. No, if you need ongoing maintenance and support—the original repository is archived, though development continues at https://github.com/triton-lang/triton-windows. Verify PyTorch and CUDA version compatibility before installing.
Install
triton-windows on PyPI
Before you install
Medium install friction: platform-specific wheels for Windows (cp310–cp314), requires matching Python environment and GPU driver setup. Repository is archived; development has moved to https://github.com/triton-lang/triton-windows, but pip installation continues to work.
Requires Windows 10 or 11, NVIDIA GPU with supported compute capability, matching PyTorch version (e.g., PyTorch 2.7 requires Triton 3.3), and correct Python environment setup (embedded, system-wide, conda, or venv).
License in practice
Permissive license (MIT) means you can use this package freely in commercial and private projects without restriction.
Quickstart
pip install triton-windows
import triton
@triton.jit
def kernel(x_ptr, output_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
mask = offsets < n_elements
x = tl.load(x_ptr + offsets, mask=mask)
tl.store(output_ptr + offsets, x, mask=mask)
Verify before relying
- Whether AMD GPU support via the referenced pull request is production-ready or experimental.
- Current status and stability of free-threaded Python (3.13t/3.14t) support on Windows.
- Whether Proton profiler limitations affect your profiling workflow.
- Specific GPU compute capability requirements for different Triton versions on Windows.
Package facts
| License | permissive license permissive |
| Python support | Supports the current Python release <3.15,>=3.10 |
| Install friction | Medium. Platform-specific wheel |
| Runtime dependencies | 1 packageimportlib-metadata |
| Maintenance | Abandoned 54 days since the last release |
| Last repo commit | repository archived |
| First released | |
| Downloads | 471,577 / month, #6,479 on PyPI 30-day window, as of 2026-08-14 |
| Known vulnerabilities | None known OSV.dev, checked 2026-08-14 |
| Classifiers | Development Status :: 4 - BetaIntended Audience :: DevelopersLicense :: OSI Approved :: MIT LicenseProgramming Language :: Python :: 3.10Programming Language :: Python :: 3.11Programming Language :: Python :: 3.12Programming Language :: Python :: 3.13Programming Language :: Python :: 3.14Topic :: Software Development :: Build Tools |
Evidence: triton_windows-3.7.1.post27-cp310-cp310-win_amd64.whl; triton_windows-3.7.1.post27-cp311-cp311-win_amd64.whl; triton_windows-3.7.1.post27-cp312-cp312-win_amd64.whl; triton_windows-3.7.1.post27-cp313-cp313-win_amd64.whl; triton_windows-3.7.1.post27-cp314-cp314-win_amd64.whl
Tags
Let your AI agent find packages like this
Example. Real query, live index.
You found this page by searching. An agent finds it by wishing: SkillFed indexes 14,416 PyPI packages by what they can do, searchable in plain language.
wish › “GPU kernel compiler windows”
- triton-windowsTriton-windows is a Windows port of the Triton compiler that lets you…
- nvidia-cuda-nvrtc-cu12Provides NVIDIA CUDA NVRTC native runtime libraries for compiling…
- quadrantsQuadrants is a high-performance compiler that translates Python code…
Give your agent the search over MCP, or paste the wish link into any chat.
More Build Tools packages
Provides reusable utilities for Python packaging interoperability, including version handling, specifiers, markers, requirements, tags, and metadata parsing according to standards like PEP 440 and PEP 425.
Wraps any iterable to display a real-time progress bar in the terminal or Jupyter notebook, showing iteration count, elapsed time, and estimated time remaining.
pip is the standard installer for Python packages, enabling you to download and install packages from the Python Package Index and other indexes into your Python environment.
Hatchling is a standards-compliant Python build backend that handles packaging, metadata, and distribution of Python projects when configured in a project's pyproject.toml file.
Generates Python gRPC service stubs and message classes from Protocol Buffer definitions, enabling developers to build gRPC clients and servers.
pre-commit is a framework for installing and running git hooks written in any language before commits are made, automating code quality and validation checks across multi-language projects.
Install it if your team needs consistent, automated validation at commit time.
See also tokenspeed-triton · triton · triton-ascend · nvidia-cuda-nvrtc-cu12 · nvidia-cuda-nvcc · helion · nvidia-cuda-nvcc-cu12 · nvidia-cuda-nvrtc · tritonclient · perf-analyzer